@@ -1,7 +1,6 @@
-from collectd_rest.rrd import render
+from collectd_rest.rrd import render, RRDError
 from django.db import models
 from django.core.exceptions import ValidationError
-import subprocess
 
 class GraphGroup(models.Model):
 	name = models.CharField(max_length=256, blank = False, null = True, unique = True)
@@ -20,6 +19,6 @@ class Graph(models.Model):
 	def clean(self):
 		try:
 			render(self.command, 'PNG')
-		except subprocess.CalledProcessError as e:
-			raise ValidationError({'command':e.output})
+		except RRDError as e:
+			raise ValidationError({'command':e.message})
 
